@@ -8,6 +8,6 @@ StrOrListOfStrs = Union[str, ListOfStrs]
 Result = Any
 Results = List[Result]
 ResultOrResults = Union[Result, Results]
-StrOrView = Union[str, 'ItemView']
-RunnerArgs = Union[str, List[str], 'ItemView', List['ItemView']]
+StrOrView = Union[str, "ItemView"]
+RunnerArgs = Union[str, List[str], "ItemView", List["ItemView"]]
 IterativeResults = List[Tuple[Tuple[Dict[str, Any], ...], Tuple[Any]]]
\ No newline at end of file
